# -*- coding: utf-8 -*-
# BSD 3-Clause License
#
# Copyright (c) 2017, Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
# * Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
Nuage VSD Sim utils
"""

import ConfigParser
import logging
import re
import sys
import uuid

from vspk import v5_0 as vsdk

NUAGE_API_DATA = {
    'ROOT_UUIDS': {
        'csproot_user': '',
        'csp_enterprise': ''
    },
    'addressmap': {},
    'patnatpool_addressmap': {'_TYPE': 'child'},
    'addressrange': {},
    'l2domaintemplate_addressrange': {'_TYPE': 'child'},
    'subnet_addressrange': {'_TYPE': 'child'},
    'sharednetworkresource_addressrange': {'_TYPE': 'child'},
    'l2domain_addressrange': {'_TYPE': 'child'},
    'subnettemplate_addressrange': {'_TYPE': 'child'},
    'aggregatemetadata': {},
    'vport_aggregatemetadata': {'_TYPE': 'child'},
    'alarm': {},
    'vrs_alarm': {'_TYPE': 'child'},
    'ikegatewayconnection_alarm': {'_TYPE': 'child'},
    'nsgredundancygroup_alarm': {'_TYPE': 'child'},
    'container_alarm': {'_TYPE': 'child'},
    'vsgredundantport_alarm': {'_TYPE': 'child'},
    'service_alarm': {'_TYPE': 'child'},
    'hsc_alarm': {'_TYPE': 'child'},
    'nsport_alarm': {'_TYPE': 'child'},
    'vlan_alarm': {'_TYPE': 'child'},
    'vm_alarm': {'_TYPE': 'child'},
    'ssidconnection_alarm': {'_TYPE': 'child'},
    'nsgateway_alarm': {'_TYPE': 'child'},
    'vsc_alarm': {'_TYPE': 'child'},
    'vsd_alarm': {'_TYPE': 'child'},
    'enterprise_alarm': {'_TYPE': 'child'},
    'redundancygroup_alarm': {'_TYPE': 'child'},
    'vport_alarm': {'_TYPE': 'child'},
    'gateway_alarm': {'_TYPE': 'child'},
    'port_alarm': {'_TYPE': 'child'},
    'wirelessport_alarm': {'_TYPE': 'child'},
    'tca_alarm': {'_TYPE': 'child'},
    'allalarm': {},
    'enterprise_allalarm': {'_TYPE': 'child'},
    'application': {},
    'l7applicationsignature_application': {'_TYPE': 'child'},
    'enterprise_application': {'_TYPE': 'child'},
    'applicationbinding': {},
    'applicationperformancemanagement_applicationbinding': {'_TYPE': 'child'},
    'application_applicationbinding': {'_TYPE': 'member'},
    'applicationperformancemanagement': {},
    'vport_applicationperformancemanagement': {'_TYPE': 'member'},
    'performancemonitor_applicationperformancemanagement': {'_TYPE': 'member'},
    'enterprise_applicationperformancemanagement': {'_TYPE': 'child'},
    'applicationperformancemanagementbinding': {},
    'domain_applicationperformancemanagementbinding': {'_TYPE': 'child'},
    'autodiscoveredcluster': {},
    'vcenterdatacenter_autodiscoveredcluster': {'_TYPE': 'child'},
    'autodiscovereddatacenter': {},
    'vcenter_autodiscovereddatacenter': {'_TYPE': 'child'},
    'autodiscoveredgateway': {},
    'autodiscoveredhypervisor': {},
    'vcentercluster_autodiscoveredhypervisor': {'_TYPE': 'child'},
    'vcenterdatacenter_autodiscoveredhypervisor': {'_TYPE': 'child'},
    'avatar': {},
    'user_avatar': {'_TYPE': 'child'},
    'enterprise_avatar': {'_TYPE': 'child'},
    'bfdsession': {},
    'brconnection_bfdsession': {'_TYPE': 'child'},
    'uplinkconnection_bfdsession': {'_TYPE': 'child'},
    'bgpneighbor': {},
    'subnet_bgpneighbor': {'_TYPE': 'child'},
    'vport_bgpneighbor': {'_TYPE': 'child'},
    'vlan_bgpneighbor': {'_TYPE': 'child'},
    'bgppeer': {},
    'hsc_bgppeer': {'_TYPE': 'child'},
    'vsc_bgppeer': {'_TYPE': 'child'},
    'bgpprofile': {},
    'enterprise_bgpprofile': {'_TYPE': 'child'},
    'bootstrap': {},
    'nsgateway_bootstrap': {'_TYPE': 'child'},
    'bootstrapactivation': {},
    'nsgateway_bootstrapactivation': {'_TYPE': 'child'},
    'brconnection': {},
    'vlan_brconnection': {'_TYPE': 'child'},
    'vlantemplate_brconnection': {'_TYPE': 'child'},
    'bridgeinterface': {},
    'domain_bridgeinterface': {'_TYPE': 'child'},
    'l2domain_bridgeinterface': {'_TYPE': 'child'},
    'vport_bridgeinterface': {'_TYPE': 'child'},
    'bulkstatistics': {},
    'patnatpool_bulkstatistics': {'_TYPE': 'child'},
    'captiveportalprofile': {},
    'enterprise_captiveportalprofile': {'_TYPE': 'child'},
    'ssidconnection_captiveportalprofile': {'_TYPE': 'member'},
    'certificate': {},
    'cms': {},
    'command': {},
    'nsgateway_command': {'_TYPE': 'child'},
    'component': {},
    'vsd_component': {'_TYPE': 'child'},
    'connectionendpoint': {},
    'infrastructureaccessprofile_connectionendpoint': {'_TYPE': 'child'},
    'container': {},
    'vrs_container': {'_TYPE': 'child'},
    'subnet_container': {'_TYPE': 'child'},
    'domain_container': {'_TYPE': 'child'},
    'qos_container': {'_TYPE': 'child'},
    'zone_container': {'_TYPE': 'child'},
    'egressacltemplate_container': {'_TYPE': 'child'},
    'l2domain_container': {'_TYPE': 'child'},
    'user_container': {'_TYPE': 'child'},
    'enterprise_container': {'_TYPE': 'child'},
    'vport_container': {'_TYPE': 'child'},
    'ingressacltemplate_container': {'_TYPE': 'child'},
    'containerinterface': {},
    'subnet_containerinterface': {'_TYPE': 'child'},
    'domain_containerinterface': {'_TYPE': 'child'},
    'container_containerinterface': {'_TYPE': 'child'},
    'zone_containerinterface': {'_TYPE': 'child'},
    'l2domain_containerinterface': {'_TYPE': 'child'},
    'vport_containerinterface': {'_TYPE': 'child'},
    'containerresync': {},
    'subnet_containerresync': {'_TYPE': 'child'},
    'container_containerresync': {'_TYPE': 'child'},
    'cosremarkingpolicy': {},
    'cosremarkingpolicytable_cosremarkingpolicy': {'_TYPE': 'child'},
    'cosremarkingpolicytable': {},
    'enterprise_cosremarkingpolicytable': {'_TYPE': 'child'},
    'csnatpool': {},
    'link_csnatpool': {'_TYPE': 'child'},
    'ctranslationmap': {},
    'csnatpool_ctranslationmap': {'_TYPE': 'child'},
    'customproperty': {},
    'uplinkconnection_customproperty': {'_TYPE': 'child'},
    'demarcationservice': {},
    'link_demarcationservice': {'_TYPE': 'child'},
    'destinationurl': {},
    'tier_destinationurl': {'_TYPE': 'child'},
    'dhcpoption': {},
    'containerinterface_dhcpoption': {'_TYPE': 'child'},
    'subnet_dhcpoption': {'_TYPE': 'child'},
    'domain_dhcpoption': {'_TYPE': 'child'},
    'zone_dhcpoption': {'_TYPE': 'child'},
    'sharednetworkresource_dhcpoption': {'_TYPE': 'child'},
    'hostinterface_dhcpoption': {'_TYPE': 'child'},
    'bridgeinterface_dhcpoption': {'_TYPE': 'child'},
    'vminterface_dhcpoption': {'_TYPE': 'child'},
    'vport_dhcpoption': {'_TYPE': 'child'},
    'l2domain_dhcpoption': {'_TYPE': 'child'},
    'diskstat': {},
    'domain': {},
    'domain_domain': {'_TYPE': 'member'},
    'enterprise_domain': {'_TYPE': 'child'},
    'domaintemplate_domain': {'_TYPE': 'member'},
    'firewallacl_domain': {'_TYPE': 'child'},
    'domaintemplate': {},
    'domain_domaintemplate': {'_TYPE': 'child'},
    'enterprise_domaintemplate': {'_TYPE': 'child'},
    'dscpforwardingclassmapping': {},
    'dscpforwardingclasstable_dscpforwardingclassmapping': {'_TYPE': 'child'},
    'dscpforwardingclasstable': {},
    'enterprise_dscpforwardingclasstable': {'_TYPE': 'child'},
    'dscpremarkingpolicy': {},
    'dscpremarkingpolicytable_dscpremarkingpolicy': {'_TYPE': 'child'},
    'dscpremarkingpolicytable': {},
    'enterprise_dscpremarkingpolicytable': {'_TYPE': 'child'},
    'ducgroup': {},
    'ducgroupbinding': {},
    'nsggroup_ducgroupbinding': {'_TYPE': 'child'},
    'eamconfig': {},
    'egressaclentrytemplate': {},
    'domain_egressaclentrytemplate': {'_TYPE': 'child'},
    'egressacltemplate_egressaclentrytemplate': {'_TYPE': 'child'},
    'l2domain_egressaclentrytemplate': {'_TYPE': 'child'},
    'mirrordestination_egressaclentrytemplate': {'_TYPE': 'child'},
    'vport_egressaclentrytemplate': {'_TYPE': 'child'},
    'egressacltemplate': {},
    'l2domaintemplate_egressacltemplate': {'_TYPE': 'child'},
    'domain_egressacltemplate': {'_TYPE': 'child'},
    'domaintemplate_egressacltemplate': {'_TYPE': 'child'},
    'l2domain_egressacltemplate': {'_TYPE': 'child'},
    'egressadvfwdentrytemplate': {},
    'egressadvfwdtemplate_egressadvfwdentrytemplate': {'_TYPE': 'child'},
    'egressadvfwdtemplate': {},
    'l2domaintemplate_egressadvfwdtemplate': {'_TYPE': 'child'},
    'domain_egressadvfwdtemplate': {'_TYPE': 'child'},
    'domaintemplate_egressadvfwdtemplate': {'_TYPE': 'child'},
    'l2domain_egressadvfwdtemplate': {'_TYPE': 'child'},
    'egressdomainfloatingipaclentrytemplate': {},
    'egressdomainfloatingipacltemplate_egressdomainfloatingipaclentrytemplate': {'_TYPE': 'child'},
    'egressdomainfloatingipacltemplate': {},
    'domain_egressdomainfloatingipacltemplate': {'_TYPE': 'child'},
    'domaintemplate_egressdomainfloatingipacltemplate': {'_TYPE': 'child'},
    'egressfloatingipaclentrytemplate': {},
    'egressfloatingipacltemplate_egressfloatingipaclentrytemplate': {'_TYPE': 'child'},
    'egressfloatingipacltemplate': {},
    'domain_egressfloatingipacltemplate': {'_TYPE': 'child'},
    'domaintemplate_egressfloatingipacltemplate': {'_TYPE': 'child'},
    'egressqospolicy': {},
    'enterprise_egressqospolicy': {'_TYPE': 'child'},
    'enterprise': {},
    'enterpriseprofile_enterprise': {'_TYPE': 'child'},
    'enterprisenetwork': {},
    'networkmacrogroup_enterprisenetwork': {'_TYPE': 'member'},
    'enterprise_enterprisenetwork': {'_TYPE': 'child'},
    'enterprisepermission': {},
    'subnet_enterprisepermission': {'_TYPE': 'child'},
    'vsgredundantport_enterprisepermission': {'_TYPE': 'child'},
    'service_enterprisepermission': {'_TYPE': 'child'},
    'patnatpool_enterprisepermission': {'_TYPE': 'child'},
    'sharednetworkresource_enterprisepermission': {'_TYPE': 'child'},
    'vlan_enterprisepermission': {'_TYPE': 'child'},
    'gateway_enterprisepermission': {'_TYPE': 'child'},
    'nsgateway_enterprisepermission': {'_TYPE': 'child'},
    'redundancygroup_enterprisepermission': {'_TYPE': 'child'},
    'nsport_enterprisepermission': {'_TYPE': 'child'},
    'port_enterprisepermission': {'_TYPE': 'child'},
    'enterpriseprofile': {},
    'enterprisesecureddata': {},
    'enterprisesecurity_enterprisesecureddata': {'_TYPE': 'child'},
    'enterprisesecurity': {},
    'enterprise_enterprisesecurity': {'_TYPE': 'child'},
    'eventlog': {},
    'containerinterface_eventlog': {'_TYPE': 'child'},
    'vsp_eventlog': {'_TYPE': 'child'},
    'domain_eventlog': {'_TYPE': 'child'},
    'policygroup_eventlog': {'_TYPE': 'child'},
    'qos_eventlog': {'_TYPE': 'child'},
    'autodiscoveredgateway_eventlog': {'_TYPE': 'child'},
    'proxyarpfilter_eventlog': {'_TYPE': 'child'},
    'l2domaintemplate_eventlog': {'_TYPE': 'child'},
    'addressrange_eventlog': {'_TYPE': 'child'},
    'domaintemplate_eventlog': {'_TYPE': 'child'},
    'vm_eventlog': {'_TYPE': 'child'},
    'virtualip_eventlog': {'_TYPE': 'child'},
    'vsc_eventlog': {'_TYPE': 'child'},
    'vsd_eventlog': {'_TYPE': 'child'},
    'enterprise_eventlog': {'_TYPE': 'child'},
    'redundancygroup_eventlog': {'_TYPE': 'child'},
    'vport_eventlog': {'_TYPE': 'child'},
    'port_eventlog': {'_TYPE': 'child'},
    'tca_eventlog': {'_TYPE': 'child'},
    'subnet_eventlog': {'_TYPE': 'child'},
    'group_eventlog': {'_TYPE': 'child'},
    'publicnetwork_eventlog': {'_TYPE': 'child'},
    'service_eventlog': {'_TYPE': 'child'},
    'floatingip_eventlog': {'_TYPE': 'child'},
    'egressacltemplate_eventlog': {'_TYPE': 'child'},
    'gateway_eventlog': {'_TYPE': 'child'},
    'nsgredundancygroup_eventlog': {'_TYPE': 'child'},
    'metadata_eventlog': {'_TYPE': 'child'},
    'vrs_eventlog': {'_TYPE': 'child'},
    'hsc_eventlog': {'_TYPE': 'child'},
    'enterprisenetwork_eventlog': {'_TYPE': 'child'},
    'permission_eventlog': {'_TYPE': 'child'},
    'l2domain_eventlog': {'_TYPE': 'child'},
    'vlan_eventlog': {'_TYPE': 'child'},
    'wirelessport_eventlog': {'_TYPE': 'child'},
    'staticroute_eventlog': {'_TYPE': 'child'},
    'ipreservation_eventlog': {'_TYPE': 'child'},
    'vminterface_eventlog': {'_TYPE': 'child'},
    'hostinterface_eventlog': {'_TYPE': 'child'},
    'redirectiontargettemplate_eventlog': {'_TYPE': 'child'},
    'subnettemplate_eventlog': {'_TYPE': 'child'},
    'container_eventlog': {'_TYPE': 'child'},
    'ssidconnection_eventlog': {'_TYPE': 'child'},
    'redirectiontarget_eventlog': {'_TYPE': 'child'},
    'zone_eventlog': {'_TYPE': 'child'},
    'license_eventlog': {'_TYPE': 'child'},
    'enterpriseprofile_eventlog': {'_TYPE': 'child'},
    'nsport_eventlog': {'_TYPE': 'child'},
    'dhcpoption_eventlog': {'_TYPE': 'child'},
    'policygrouptemplate_eventlog': {'_TYPE': 'child'},
    'bridgeinterface_eventlog': {'_TYPE': 'child'},
    'nsgateway_eventlog': {'_TYPE': 'child'},
    'zonetemplate_eventlog': {'_TYPE': 'child'},
    'multicastrange_eventlog': {'_TYPE': 'child'},
    'multicastchannelmap_eventlog': {'_TYPE': 'child'},
    'ingressacltemplate_eventlog': {'_TYPE': 'child'},
    'user_eventlog': {'_TYPE': 'child'},
    'firewallacl': {},
    'domain_firewallacl': {'_TYPE': 'child'},
    'enterprise_firewallacl': {'_TYPE': 'child'},
    'firewallrule': {},
    'enterprise_firewallrule': {'_TYPE': 'child'},
    'firewallacl_firewallrule': {'_TYPE': 'child'},
    'floatingip': {},
    'domain_floatingip': {'_TYPE': 'child'},
    'gateway': {},
    'redundancygroup_gateway': {'_TYPE': 'child'},
    'enterprise_gateway': {'_TYPE': 'child'},
    'gatewaysecureddata': {},
    'gatewaysecurity_gatewaysecureddata': {'_TYPE': 'child'},
    'gatewaysecurity': {},
    'nsgateway_gatewaysecurity': {'_TYPE': 'child'},
    'gatewaytemplate': {},
    'enterprise_gatewaytemplate': {'_TYPE': 'child'},
    'globalmetadata': {},
    'containerinterface_globalmetadata': {'_TYPE': 'child'},
    'groupkeyencryptionprofile_globalmetadata': {'_TYPE': 'child'},
    'qos_globalmetadata': {'_TYPE': 'child'},
    'infrastructureaccessprofile_globalmetadata': {'_TYPE': 'child'},
    'bgppeer_globalmetadata': {'_TYPE': 'child'},
    'sharednetworkresource_globalmetadata': {'_TYPE': 'child'},
    'virtualip_globalmetadata': {'_TYPE': 'child'},
    'egressadvfwdentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'dscpforwardingclasstable_globalmetadata': {'_TYPE': 'child'},
    'multicastchannelmap_globalmetadata': {'_TYPE': 'child'},
    'enterprise_globalmetadata': {'_TYPE': 'child'},
    'redundancygroup_globalmetadata': {'_TYPE': 'child'},
    'tca_globalmetadata': {'_TYPE': 'child'},
    'ikesubnet_globalmetadata': {'_TYPE': 'child'},
    'group_globalmetadata': {'_TYPE': 'child'},
    'autodiscoveredgateway_globalmetadata': {'_TYPE': 'child'},
    'zone_globalmetadata': {'_TYPE': 'child'},
    'ikegatewayprofile_globalmetadata': {'_TYPE': 'child'},
    'overlaymirrordestination_globalmetadata': {'_TYPE': 'child'},
    'infrastructuregatewayprofile_globalmetadata': {'_TYPE': 'child'},
    'eamconfig_globalmetadata': {'_TYPE': 'child'},
    'location_globalmetadata': {'_TYPE': 'child'},
    'enterprisesecurity_globalmetadata': {'_TYPE': 'child'},
    'vrsconfig_globalmetadata': {'_TYPE': 'child'},
    'enterprisenetwork_globalmetadata': {'_TYPE': 'child'},
    'infrastructurevscprofile_globalmetadata': {'_TYPE': 'child'},
    'permission_globalmetadata': {'_TYPE': 'child'},
    'cosremarkingpolicy_globalmetadata': {'_TYPE': 'child'},
    'ipreservation_globalmetadata': {'_TYPE': 'child'},
    'redirectiontargettemplate_globalmetadata': {'_TYPE': 'child'},
    'subnettemplate_globalmetadata': {'_TYPE': 'child'},
    'egressfloatingipacltemplate_globalmetadata': {'_TYPE': 'child'},
    'ikegatewayconnection_globalmetadata': {'_TYPE': 'child'},
    'redirectiontarget_globalmetadata': {'_TYPE': 'child'},
    'networklayout_globalmetadata': {'_TYPE': 'child'},
    'ingressexternalserviceentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'avatar_globalmetadata': {'_TYPE': 'child'},
    'bootstrapactivation_globalmetadata': {'_TYPE': 'child'},
    'cms_globalmetadata': {'_TYPE': 'child'},
    'vsp_globalmetadata': {'_TYPE': 'child'},
    'domain_globalmetadata': {'_TYPE': 'child'},
    'nsredundantport_globalmetadata': {'_TYPE': 'child'},
    'dscpforwardingclassmapping_globalmetadata': {'_TYPE': 'child'},
    'egressaclentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'vsc_globalmetadata': {'_TYPE': 'child'},
    'vsd_globalmetadata': {'_TYPE': 'child'},
    'vport_globalmetadata': {'_TYPE': 'child'},
    'vpnconnection_globalmetadata': {'_TYPE': 'child'},
    'statisticspolicy_globalmetadata': {'_TYPE': 'child'},
    'subnet_globalmetadata': {'_TYPE': 'child'},
    'container_globalmetadata': {'_TYPE': 'child'},
    'ratelimiter_globalmetadata': {'_TYPE': 'child'},
    'keyservermonitorencryptedseed_globalmetadata': {'_TYPE': 'child'},
    'uplinkroutedistinguisher_globalmetadata': {'_TYPE': 'child'},
    'keyservermonitorseed_globalmetadata': {'_TYPE': 'child'},
    'gatewaytemplate_globalmetadata': {'_TYPE': 'child'},
    'vrs_globalmetadata': {'_TYPE': 'child'},
    'hsc_globalmetadata': {'_TYPE': 'child'},
    'overlaymirrordestinationtemplate_globalmetadata': {'_TYPE': 'child'},
    'ldapconfiguration_globalmetadata': {'_TYPE': 'child'},
    'component_globalmetadata': {'_TYPE': 'child'},
    'zfbrequest_globalmetadata': {'_TYPE': 'child'},
    'enterprisepermission_globalmetadata': {'_TYPE': 'child'},
    'staticroute_globalmetadata': {'_TYPE': 'child'},
    'job_globalmetadata': {'_TYPE': 'child'},
    'vminterface_globalmetadata': {'_TYPE': 'child'},
    'gatewaysecureddata_globalmetadata': {'_TYPE': 'child'},
    'vcenterhypervisor_globalmetadata': {'_TYPE': 'child'},
    'keyservermonitor_globalmetadata': {'_TYPE': 'child'},
    'qospolicer_globalmetadata': {'_TYPE': 'child'},
    'service_globalmetadata': {'_TYPE': 'child'},
    'license_globalmetadata': {'_TYPE': 'child'},
    'enterpriseprofile_globalmetadata': {'_TYPE': 'child'},
    'egressfloatingipaclentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'bridgeinterface_globalmetadata': {'_TYPE': 'child'},
    'infraconfig_globalmetadata': {'_TYPE': 'child'},
    'dscpremarkingpolicy_globalmetadata': {'_TYPE': 'child'},
    'networkmacrogroup_globalmetadata': {'_TYPE': 'child'},
    'ingressadvfwdentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'multicastlist_globalmetadata': {'_TYPE': 'child'},
    'destinationurl_globalmetadata': {'_TYPE': 'child'},
    'vsgredundantport_globalmetadata': {'_TYPE': 'child'},
    'nexthop_globalmetadata': {'_TYPE': 'child'},
    'mirrordestination_globalmetadata': {'_TYPE': 'child'},
    'natmapentry_globalmetadata': {'_TYPE': 'child'},
    'egressdomainfloatingipacltemplate_globalmetadata': {'_TYPE': 'child'},
    'ospfinterface_globalmetadata': {'_TYPE': 'child'},
    'cosremarkingpolicytable_globalmetadata': {'_TYPE': 'child'},
    'addressmap_globalmetadata': {'_TYPE': 'child'},
    'gateway_globalmetadata': {'_TYPE': 'child'},
    'multinicvport_globalmetadata': {'_TYPE': 'child'},
    'bfdsession_globalmetadata': {'_TYPE': 'child'},
    'statistics_globalmetadata': {'_TYPE': 'child'},
    'nsporttemplate_globalmetadata': {'_TYPE': 'child'},
    'eventlog_globalmetadata': {'_TYPE': 'child'},
    'vcenterdatacenter_globalmetadata': {'_TYPE': 'child'},
    'ltestatistics_globalmetadata': {'_TYPE': 'child'},
    'virtualfirewallrule_globalmetadata': {'_TYPE': 'child'},
    'virtualfirewallpolicy_globalmetadata': {'_TYPE': 'child'},
    'dscpremarkingpolicytable_globalmetadata': {'_TYPE': 'child'},
    'ikegateway_globalmetadata': {'_TYPE': 'child'},
    'statisticscollector_globalmetadata': {'_TYPE': 'child'},
    'vcenter_globalmetadata': {'_TYPE': 'child'},
    'bulkstatistics_globalmetadata': {'_TYPE': 'child'},
    'ingressaclentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'routingpolicy_globalmetadata': {'_TYPE': 'child'},
    'multicastrange_globalmetadata': {'_TYPE': 'child'},
    'certificate_globalmetadata': {'_TYPE': 'child'},
    'l2domain_globalmetadata': {'_TYPE': 'child'},
    'ikegatewayconfig_globalmetadata': {'_TYPE': 'child'},
    'hostinterface_globalmetadata': {'_TYPE': 'child'},
    'enterprisesecureddata_globalmetadata': {'_TYPE': 'child'},
    'ikecertificate_globalmetadata': {'_TYPE': 'child'},
    'ingressexternalservicetemplate_globalmetadata': {'_TYPE': 'child'},
    'porttemplate_globalmetadata': {'_TYPE': 'child'},
    'egressadvfwdtemplate_globalmetadata': {'_TYPE': 'child'},
    'ospfinstance_globalmetadata': {'_TYPE': 'child'},
    'dhcpoption_globalmetadata': {'_TYPE': 'child'},
    'keyservermember_globalmetadata': {'_TYPE': 'child'},
    'nsgateway_globalmetadata': {'_TYPE': 'child'},
    'nsgatewaytemplate_globalmetadata': {'_TYPE': 'child'},
    'zonetemplate_globalmetadata': {'_TYPE': 'child'},
    'site_globalmetadata': {'_TYPE': 'child'},
    'alarm_globalmetadata': {'_TYPE': 'child'},
    'nsgroutingpolicybinding_globalmetadata': {'_TYPE': 'child'},
    'bootstrap_globalmetadata': {'_TYPE': 'child'},
    'bgpprofile_globalmetadata': {'_TYPE': 'child'},
    'egressqospolicy_globalmetadata': {'_TYPE': 'child'},
    'publicnetwork_globalmetadata': {'_TYPE': 'child'},
    'l2domaintemplate_globalmetadata': {'_TYPE': 'child'},
    'ingressqospolicy_globalmetadata': {'_TYPE': 'child'},
    'addressrange_globalmetadata': {'_TYPE': 'child'},
    'domaintemplate_globalmetadata': {'_TYPE': 'child'},
    'vm_globalmetadata': {'_TYPE': 'child'},
    'egressdomainfloatingipaclentrytemplate_globalmetadata': {'_TYPE': 'child'},
    'resync_globalmetadata': {'_TYPE': 'child'},
    'policydecision_globalmetadata': {'_TYPE': 'child'},
    'floatingip_globalmetadata': {'_TYPE': 'child'},
    'egressacltemplate_globalmetadata': {'_TYPE': 'child'},
    'monitoringport_globalmetadata': {'_TYPE': 'child'},
    'port_globalmetadata': {'_TYPE': 'child'},
    'nsgredundancygroup_globalmetadata': {'_TYPE': 'child'},
    'keyservermonitorsek_globalmetadata': {'_TYPE': 'child'},
    'ingressadvfwdtemplate_globalmetadata': {'_TYPE': 'child'},
    'vportmirror_globalmetadata': {'_TYPE': 'child'},
    'patnatpool_globalmetadata': {'_TYPE': 'child'},
    'bgpneighbor_globalmetadata': {'_TYPE': 'child'},
    'containerresync_globalmetadata': {'_TYPE': 'child'},
    'allalarm_globalmetadata': {'_TYPE': 'child'},
    'vlan_globalmetadata': {'_TYPE': 'child'},
    'systemconfig_globalmetadata': {'_TYPE': 'child'},
    'ikeencryptionprofile_globalmetadata': {'_TYPE': 'child'},
    'policygrouptemplate_globalmetadata': {'_TYPE': 'child'},
    'vcentercluster_globalmetadata': {'_TYPE': 'child'},
    'user_globalmetadata': {'_TYPE': 'child'},
    'tier_globalmetadata': {'_TYPE': 'child'},
    'policygroup_globalmetadata': {'_TYPE': 'child'},
    'nsport_globalmetadata': {'_TYPE': 'child'},
    'vrsaddressrange_globalmetadata': {'_TYPE': 'child'},
    'vlantemplate_globalmetadata': {'_TYPE': 'child'},
    'gatewaysecurity_globalmetadata': {'_TYPE': 'child'},
    'globalmetadata_globalmetadata': {'_TYPE': 'child'},
    'ospfarea_globalmetadata': {'_TYPE': 'child'},
    'ikepsk_globalmetadata': {'_TYPE': 'child'},
    'link_globalmetadata': {'_TYPE': 'child'},
    'ingressacltemplate_globalmetadata': {'_TYPE': 'child'},
    'group': {},
    'domain_group': {'_TYPE': 'child'},
    'zone_group': {'_TYPE': 'child'},
    'l2domaintemplate_group': {'_TYPE': 'child'},
    'l2domain_group': {'_TYPE': 'child'},
    'domaintemplate_group': {'_TYPE': 'child'},
    'user_group': {'_TYPE': 'child'},
    'enterprise_group': {'_TYPE': 'child'},
    'groupkeyencryptionprofile': {},
    'enterprise_groupkeyencryptionprofile': {'_TYPE': 'child'},
    'hostinterface': {},
    'domain_hostinterface': {'_TYPE': 'child'},
    'l2domain_hostinterface': {'_TYPE': 'child'},
    'vport_hostinterface': {'_TYPE': 'child'},
    'hsc': {},
    'vsp_hsc': {'_TYPE': 'child'},
    'vrs_hsc': {'_TYPE': 'child'},
    'ikecertificate': {},
    'enterprise_ikecertificate': {'_TYPE': 'child'},
    'ikeencryptionprofile': {},
    'enterprise_ikeencryptionprofile': {'_TYPE': 'child'},
    'ikegateway': {},
    'enterprise_ikegateway': {'_TYPE': 'child'},
    'ikegatewayconfig': {},
    'ikegateway_ikegatewayconfig': {'_TYPE': 'member'},
    'ikegatewayconnection': {},
    'subnet_ikegatewayconnection': {'_TYPE': 'member'},
    'vlan_ikegatewayconnection': {'_TYPE': 'child'},
    'ikegatewayprofile': {},
    'enterprise_ikegatewayprofile': {'_TYPE': 'child'},
    'ikepsk': {},
    'enterprise_ikepsk': {'_TYPE': 'child'},
    'ikesubnet': {},
    'ikegateway_ikesubnet': {'_TYPE': 'child'},
    'infraconfig': {},
    'nsgateway_infraconfig': {'_TYPE': 'child'},
    'infrastructureaccessprofile': {},
    'infrastructuregatewayprofile': {},
    'infrastructurevscprofile': {},
    'ingressaclentrytemplate': {},
    'domain_ingressaclentrytemplate': {'_TYPE': 'child'},
    'l2domain_ingressaclentrytemplate': {'_TYPE': 'child'},
    'mirrordestination_ingressaclentrytemplate': {'_TYPE': 'child'},
    'vport_ingressaclentrytemplate': {'_TYPE': 'child'},
    'ingressacltemplate_ingressaclentrytemplate': {'_TYPE': 'child'},
    'ingressacltemplate': {},
    'l2domaintemplate_ingressacltemplate': {'_TYPE': 'child'},
    'domain_ingressacltemplate': {'_TYPE': 'child'},
    'domaintemplate_ingressacltemplate': {'_TYPE': 'child'},
    'l2domain_ingressacltemplate': {'_TYPE': 'child'},
    'ingressadvfwdentrytemplate': {},
    'vport_ingressadvfwdentrytemplate': {'_TYPE': 'child'},
    'ingressadvfwdtemplate_ingressadvfwdentrytemplate': {'_TYPE': 'child'},
    'mirrordestination_ingressadvfwdentrytemplate': {'_TYPE': 'child'},
    'ingressadvfwdtemplate': {},
    'l2domaintemplate_ingressadvfwdtemplate': {'_TYPE': 'child'},
    'domain_ingressadvfwdtemplate': {'_TYPE': 'child'},
    'domaintemplate_ingressadvfwdtemplate': {'_TYPE': 'child'},
    'l2domain_ingressadvfwdtemplate': {'_TYPE': 'child'},
    'ingressexternalserviceentrytemplate': {},
    'ingressexternalservicetemplate_ingressexternalserviceentrytemplate': {'_TYPE': 'child'},
    'ingressexternalservicetemplate': {},
    'l2domaintemplate_ingressexternalservicetemplate': {'_TYPE': 'child'},
    'domain_ingressexternalservicetemplate': {'_TYPE': 'child'},
    'domaintemplate_ingressexternalservicetemplate': {'_TYPE': 'child'},
    'l2domain_ingressexternalservicetemplate': {'_TYPE': 'child'},
    'ingressqospolicy': {},
    'enterprise_ingressqospolicy': {'_TYPE': 'child'},
    'ipreservation': {},
    'subnet_ipreservation': {'_TYPE': 'child'},
    'job': {},
    'ingressadvfwdentrytemplate_job': {'_TYPE': 'child'},
    'domain_job': {'_TYPE': 'child'},
    'vnf_job': {'_TYPE': 'child'},
    'l2domaintemplate_job': {'_TYPE': 'child'},
    'domaintemplate_job': {'_TYPE': 'child'},
    'egressadvfwdentrytemplate_job': {'_TYPE': 'child'},
    'vsc_job': {'_TYPE': 'child'},
    'vsd_job': {'_TYPE': 'child'},
    'vport_job': {'_TYPE': 'child'},
    'gateway_job': {'_TYPE': 'child'},
    'policygroup_job': {'_TYPE': 'child'},
    'egressacltemplate_job': {'_TYPE': 'child'},
    'virtualfirewallrule_job': {'_TYPE': 'child'},
    'vcenter_job': {'_TYPE': 'child'},
    'ingressaclentrytemplate_job': {'_TYPE': 'child'},
    'vrs_job': {'_TYPE': 'child'},
    'hsc_job': {'_TYPE': 'child'},
    'l2domain_job': {'_TYPE': 'child'},
    'zfbrequest_job': {'_TYPE': 'child'},
    'ingressadvfwdtemplate_job': {'_TYPE': 'child'},
    'policygrouptemplate_job': {'_TYPE': 'child'},
    'vcentercluster_job': {'_TYPE': 'child'},
    'redirectiontargettemplate_job': {'_TYPE': 'child'},
    'vcenterhypervisor_job': {'_TYPE': 'child'},
    'ingressexternalservicetemplate_job': {'_TYPE': 'child'},
    'egressadvfwdtemplate_job': {'_TYPE': 'child'},
    'redirectiontarget_job': {'_TYPE': 'child'},
    'egressaclentrytemplate_job': {'_TYPE': 'child'},
    'ingressexternalserviceentrytemplate_job': {'_TYPE': 'child'},
    'nsgateway_job': {'_TYPE': 'child'},
    'enterprise_job': {'_TYPE': 'child'},
    'ingressacltemplate_job': {'_TYPE': 'child'},
    'keyservermember': {},
    'keyservermonitor': {},
    'enterprise_keyservermonitor': {'_TYPE': 'child'},
    'keyservermonitorencryptedseed': {},
    'keyservermonitorseed_keyservermonitorencryptedseed': {'_TYPE': 'child'},
    'keyservermonitor_keyservermonitorencryptedseed': {'_TYPE': 'child'},
    'keyservermonitorseed': {},
    'keyservermonitor_keyservermonitorseed': {'_TYPE': 'child'},
    'keyservermonitorsek': {},
    'keyservermonitor_keyservermonitorsek': {'_TYPE': 'child'},
    'l2domain': {},
    'l2domaintemplate_l2domain': {'_TYPE': 'child'},
    'enterprise_l2domain': {'_TYPE': 'child'},
    'l2domaintemplate': {},
    'enterprise_l2domaintemplate': {'_TYPE': 'child'},
    'l4service': {},
    'l4servicegroup_l4service': {'_TYPE': 'member'},
    'enterprise_l4service': {'_TYPE': 'child'},
    'l4servicegroup': {},
    'enterprise_l4servicegroup': {'_TYPE': 'child'},
    'l7applicationsignature': {},
    'enterprise_l7applicationsignature': {'_TYPE': 'child'},
    'ldapconfiguration': {},
    'enterprise_ldapconfiguration': {'_TYPE': 'child'},
    'license': {},
    'licensestatus': {},
    'link': {},
    'domain_link': {'_TYPE': 'child'},
    'location': {},
    'nsgateway_location': {'_TYPE': 'child'},
    'lteinformation': {},
    'nsport_lteinformation': {'_TYPE': 'child'},
    'ltestatistics': {},
    'vlan_ltestatistics': {'_TYPE': 'child'},
    'me': {},
    'metadata': {},
    'containerinterface_metadata': {'_TYPE': 'child'},
    'groupkeyencryptionprofile_metadata': {'_TYPE': 'child'},
    'qos_metadata': {'_TYPE': 'child'},
    'infrastructureaccessprofile_metadata': {'_TYPE': 'child'},
    'bgppeer_metadata': {'_TYPE': 'child'},
    'sharednetworkresource_metadata': {'_TYPE': 'child'},
    'virtualip_metadata': {'_TYPE': 'child'},
    'egressadvfwdentrytemplate_metadata': {'_TYPE': 'child'},
    'dscpforwardingclasstable_metadata': {'_TYPE': 'child'},
    'multicastchannelmap_metadata': {'_TYPE': 'child'},
    'enterprise_metadata': {'_TYPE': 'child'},
    'redundancygroup_metadata': {'_TYPE': 'child'},
    'tca_metadata': {'_TYPE': 'child'},
    'ikesubnet_metadata': {'_TYPE': 'child'},
    'group_metadata': {'_TYPE': 'child'},
    'autodiscoveredgateway_metadata': {'_TYPE': 'child'},
    'zone_metadata': {'_TYPE': 'child'},
    'ikegatewayprofile_metadata': {'_TYPE': 'child'},
    'overlaymirrordestination_metadata': {'_TYPE': 'child'},
    'infrastructuregatewayprofile_metadata': {'_TYPE': 'child'},
    'eamconfig_metadata': {'_TYPE': 'child'},
    'location_metadata': {'_TYPE': 'child'},
    'enterprisesecurity_metadata': {'_TYPE': 'child'},
    'vrsconfig_metadata': {'_TYPE': 'child'},
    'enterprisenetwork_metadata': {'_TYPE': 'child'},
    'infrastructurevscprofile_metadata': {'_TYPE': 'child'},
    'permission_metadata': {'_TYPE': 'child'},
    'cosremarkingpolicy_metadata': {'_TYPE': 'child'},
    'ipreservation_metadata': {'_TYPE': 'child'},
    'redirectiontargettemplate_metadata': {'_TYPE': 'child'},
    'subnettemplate_metadata': {'_TYPE': 'child'},
    'egressfloatingipacltemplate_metadata': {'_TYPE': 'child'},
    'ikegatewayconnection_metadata': {'_TYPE': 'child'},
    'redirectiontarget_metadata': {'_TYPE': 'child'},
    'networklayout_metadata': {'_TYPE': 'child'},
    'ingressexternalserviceentrytemplate_metadata': {'_TYPE': 'child'},
    'avatar_metadata': {'_TYPE': 'child'},
    'bootstrapactivation_metadata': {'_TYPE': 'child'},
    'cms_metadata': {'_TYPE': 'child'},
    'vsp_metadata': {'_TYPE': 'child'},
    'domain_metadata': {'_TYPE': 'child'},
    'nsredundantport_metadata': {'_TYPE': 'child'},
    'dscpforwardingclassmapping_metadata': {'_TYPE': 'child'},
    'egressaclentrytemplate_metadata': {'_TYPE': 'child'},
    'vsc_metadata': {'_TYPE': 'child'},
    'vsd_metadata': {'_TYPE': 'child'},
    'vport_metadata': {'_TYPE': 'child'},
    'vpnconnection_metadata': {'_TYPE': 'child'},
    'statisticspolicy_metadata': {'_TYPE': 'child'},
    'subnet_metadata': {'_TYPE': 'child'},
    'container_metadata': {'_TYPE': 'child'},
    'ratelimiter_metadata': {'_TYPE': 'child'},
    'keyservermonitorencryptedseed_metadata': {'_TYPE': 'child'},
    'uplinkroutedistinguisher_metadata': {'_TYPE': 'child'},
    'keyservermonitorseed_metadata': {'_TYPE': 'child'},
    'gatewaytemplate_metadata': {'_TYPE': 'child'},
    'vrs_metadata': {'_TYPE': 'child'},
    'hsc_metadata': {'_TYPE': 'child'},
    'overlaymirrordestinationtemplate_metadata': {'_TYPE': 'child'},
    'ldapconfiguration_metadata': {'_TYPE': 'child'},
    'component_metadata': {'_TYPE': 'child'},
    'zfbrequest_metadata': {'_TYPE': 'child'},
    'enterprisepermission_metadata': {'_TYPE': 'child'},
    'staticroute_metadata': {'_TYPE': 'child'},
    'job_metadata': {'_TYPE': 'child'},
    'vminterface_metadata': {'_TYPE': 'child'},
    'gatewaysecureddata_metadata': {'_TYPE': 'child'},
    'vcenterhypervisor_metadata': {'_TYPE': 'child'},
    'keyservermonitor_metadata': {'_TYPE': 'child'},
    'qospolicer_metadata': {'_TYPE': 'child'},
    'service_metadata': {'_TYPE': 'child'},
    'license_metadata': {'_TYPE': 'child'},
    'enterpriseprofile_metadata': {'_TYPE': 'child'},
    'egressfloatingipaclentrytemplate_metadata': {'_TYPE': 'child'},
    'bridgeinterface_metadata': {'_TYPE': 'child'},
    'infraconfig_metadata': {'_TYPE': 'child'},
    'dscpremarkingpolicy_metadata': {'_TYPE': 'child'},
    'networkmacrogroup_metadata': {'_TYPE': 'child'},
    'ingressadvfwdentrytemplate_metadata': {'_TYPE': 'child'},
    'multicastlist_metadata': {'_TYPE': 'child'},
    'destinationurl_metadata': {'_TYPE': 'child'},
    'vsgredundantport_metadata': {'_TYPE': 'child'},
    'nexthop_metadata': {'_TYPE': 'child'},
    'mirrordestination_metadata': {'_TYPE': 'child'},
    'natmapentry_metadata': {'_TYPE': 'child'},
    'egressdomainfloatingipacltemplate_metadata': {'_TYPE': 'child'},
    'ospfinterface_metadata': {'_TYPE': 'child'},
    'cosremarkingpolicytable_metadata': {'_TYPE': 'child'},
    'addressmap_metadata': {'_TYPE': 'child'},
    'gateway_metadata': {'_TYPE': 'child'},
    'multinicvport_metadata': {'_TYPE': 'child'},
    'bfdsession_metadata': {'_TYPE': 'child'},
    'statistics_metadata': {'_TYPE': 'child'},
    'nsporttemplate_metadata': {'_TYPE': 'child'},
    'eventlog_metadata': {'_TYPE': 'child'},
    'vcenterdatacenter_metadata': {'_TYPE': 'child'},
    'ltestatistics_metadata': {'_TYPE': 'child'},
    'virtualfirewallrule_metadata': {'_TYPE': 'child'},
    'virtualfirewallpolicy_metadata': {'_TYPE': 'child'},
    'dscpremarkingpolicytable_metadata': {'_TYPE': 'child'},
    'ikegateway_metadata': {'_TYPE': 'child'},
    'statisticscollector_metadata': {'_TYPE': 'child'},
    'vcenter_metadata': {'_TYPE': 'child'},
    'bulkstatistics_metadata': {'_TYPE': 'child'},
    'ingressaclentrytemplate_metadata': {'_TYPE': 'child'},
    'routingpolicy_metadata': {'_TYPE': 'child'},
    'multicastrange_metadata': {'_TYPE': 'child'},
    'certificate_metadata': {'_TYPE': 'child'},
    'l2domain_metadata': {'_TYPE': 'child'},
    'ikegatewayconfig_metadata': {'_TYPE': 'child'},
    'hostinterface_metadata': {'_TYPE': 'child'},
    'enterprisesecureddata_metadata': {'_TYPE': 'child'},
    'ikecertificate_metadata': {'_TYPE': 'child'},
    'ingressexternalservicetemplate_metadata': {'_TYPE': 'child'},
    'porttemplate_metadata': {'_TYPE': 'child'},
    'egressadvfwdtemplate_metadata': {'_TYPE': 'child'},
    'ospfinstance_metadata': {'_TYPE': 'child'},
    'dhcpoption_metadata': {'_TYPE': 'child'},
    'keyservermember_metadata': {'_TYPE': 'child'},
    'nsgateway_metadata': {'_TYPE': 'child'},
    'nsgatewaytemplate_metadata': {'_TYPE': 'child'},
    'zonetemplate_metadata': {'_TYPE': 'child'},
    'site_metadata': {'_TYPE': 'child'},
    'alarm_metadata': {'_TYPE': 'child'},
    'nsgroutingpolicybinding_metadata': {'_TYPE': 'child'},
    'bootstrap_metadata': {'_TYPE': 'child'},
    'bgpprofile_metadata': {'_TYPE': 'child'},
    'egressqospolicy_metadata': {'_TYPE': 'child'},
    'publicnetwork_metadata': {'_TYPE': 'child'},
    'l2domaintemplate_metadata': {'_TYPE': 'child'},
    'ingressqospolicy_metadata': {'_TYPE': 'child'},
    'addressrange_metadata': {'_TYPE': 'child'},
    'domaintemplate_metadata': {'_TYPE': 'child'},
    'vm_metadata': {'_TYPE': 'child'},
    'egressdomainfloatingipaclentrytemplate_metadata': {'_TYPE': 'child'},
    'resync_metadata': {'_TYPE': 'child'},
    'policydecision_metadata': {'_TYPE': 'child'},
    'floatingip_metadata': {'_TYPE': 'child'},
    'egressacltemplate_metadata': {'_TYPE': 'child'},
    'monitoringport_metadata': {'_TYPE': 'child'},
    'port_metadata': {'_TYPE': 'child'},
    'nsgredundancygroup_metadata': {'_TYPE': 'child'},
    'keyservermonitorsek_metadata': {'_TYPE': 'child'},
    'ingressadvfwdtemplate_metadata': {'_TYPE': 'child'},
    'vportmirror_metadata': {'_TYPE': 'child'},
    'patnatpool_metadata': {'_TYPE': 'child'},
    'bgpneighbor_metadata': {'_TYPE': 'child'},
    'containerresync_metadata': {'_TYPE': 'child'},
    'allalarm_metadata': {'_TYPE': 'child'},
    'vlan_metadata': {'_TYPE': 'child'},
    'systemconfig_metadata': {'_TYPE': 'child'},
    'ikeencryptionprofile_metadata': {'_TYPE': 'child'},
    'policygrouptemplate_metadata': {'_TYPE': 'child'},
    'vcentercluster_metadata': {'_TYPE': 'child'},
    'user_metadata': {'_TYPE': 'child'},
    'tier_metadata': {'_TYPE': 'child'},
    'policygroup_metadata': {'_TYPE': 'child'},
    'nsport_metadata': {'_TYPE': 'child'},
    'vrsaddressrange_metadata': {'_TYPE': 'child'},
    'vlantemplate_metadata': {'_TYPE': 'child'},
    'gatewaysecurity_metadata': {'_TYPE': 'child'},
    'globalmetadata_metadata': {'_TYPE': 'child'},
    'ospfarea_metadata': {'_TYPE': 'child'},
    'ikepsk_metadata': {'_TYPE': 'child'},
    'link_metadata': {'_TYPE': 'child'},
    'ingressacltemplate_metadata': {'_TYPE': 'child'},
    'mirrordestination': {},
    'monitoringport': {},
    'vrs_monitoringport': {'_TYPE': 'child'},
    'hsc_monitoringport': {'_TYPE': 'child'},
    'vsc_monitoringport': {'_TYPE': 'child'},
    'monitorscope': {},
    'nsgateway_monitorscope': {'_TYPE': 'child'},
    'application_monitorscope': {'_TYPE': 'child'},
    'networkperformancemeasurement_monitorscope': {'_TYPE': 'child'},
    'multicastchannelmap': {},
    'containerinterface_multicastchannelmap': {'_TYPE': 'child'},
    'vminterface_multicastchannelmap': {'_TYPE': 'child'},
    'hostinterface_multicastchannelmap': {'_TYPE': 'child'},
    'multicastlist_multicastchannelmap': {'_TYPE': 'member'},
    'multicastlist': {},
    'enterpriseprofile_multicastlist': {'_TYPE': 'child'},
    'enterprise_multicastlist': {'_TYPE': 'child'},
    'multicastrange': {},
    'multicastchannelmap_multicastrange': {'_TYPE': 'child'},
    'multinicvport': {},
    'vrs_multinicvport': {'_TYPE': 'child'},
    'natmapentry': {},
    'patnatpool_natmapentry': {'_TYPE': 'child'},
    'networklayout': {},
    'networkmacrogroup': {},
    'enterprisenetwork_networkmacrogroup': {'_TYPE': 'member'},
    'enterprise_networkmacrogroup': {'_TYPE': 'child'},
    'networkperformancebinding': {},
    'networkperformancemeasurement_networkperformancebinding': {'_TYPE': 'member'},
    'domain_networkperformancebinding': {'_TYPE': 'child'},
    'l2domain_networkperformancebinding': {'_TYPE': 'child'},
    'networkperformancemeasurement': {},
    'enterprise_networkperformancemeasurement': {'_TYPE': 'child'},
    'nexthop': {},
    'link_nexthop': {'_TYPE': 'child'},
    'nsgateway': {},
    'ducgroup_nsgateway': {'_TYPE': 'member'},
    'policyobjectgroup_nsgateway': {'_TYPE': 'member'},
    'performancemonitor_nsgateway': {'_TYPE': 'member'},
    'nsgredundancygroup_nsgateway': {'_TYPE': 'child'},
    'nsggroup_nsgateway': {'_TYPE': 'member'},
    'enterprise_nsgateway': {'_TYPE': 'child'},
    'nsgatewaytemplate': {},
    'enterprise_nsgatewaytemplate': {'_TYPE': 'child'},
    'nsggroup': {},
    'enterprise_nsggroup': {'_TYPE': 'child'},
    'nsginfo': {},
    'nsgateway_nsginfo': {'_TYPE': 'child'},
    'nsgredundancygroup': {},
    'enterprise_nsgredundancygroup': {'_TYPE': 'child'},
    'nsgroutingpolicybinding': {},
    'domain_nsgroutingpolicybinding': {'_TYPE': 'child'},
    'nsgupgradeprofile': {},
    'nsport': {},
    'nsgateway_nsport': {'_TYPE': 'child'},
    'autodiscoveredgateway_nsport': {'_TYPE': 'child'},
    'nsredundantport_nsport': {'_TYPE': 'child'},
    'nsporttemplate': {},
    'nsgatewaytemplate_nsporttemplate': {'_TYPE': 'child'},
    'nsredundantport': {},
    'nsgredundancygroup_nsredundantport': {'_TYPE': 'child'},
    'ospfarea': {},
    'ospfinstance_ospfarea': {'_TYPE': 'child'},
    'ospfinstance': {},
    'domain_ospfinstance': {'_TYPE': 'child'},
    'ospfinterface': {},
    'ospfarea_ospfinterface': {'_TYPE': 'child'},
    'overlayaddresspool': {},
    'link_overlayaddresspool': {'_TYPE': 'child'},
    'overlaymirrordestination': {},
    'l2domain_overlaymirrordestination': {'_TYPE': 'child'},
    'overlaymirrordestinationtemplate': {},
    'l2domaintemplate_overlaymirrordestinationtemplate': {'_TYPE': 'child'},
    'overlaypatnatentry': {},
    'overlayaddresspool_overlaypatnatentry': {'_TYPE': 'child'},
    'patipentry': {},
    'subnet_patipentry': {'_TYPE': 'child'},
    'sharednetworkresource_patipentry': {'_TYPE': 'child'},
    'patmapper': {},
    'patnatpool': {},
    'nsgateway_patnatpool': {'_TYPE': 'member'},
    'vlan_patnatpool': {'_TYPE': 'member'},
    'gateway_patnatpool': {'_TYPE': 'child'},
    'enterprise_patnatpool': {'_TYPE': 'child'},
    'performancemonitor': {},
    'ikegatewayconnection_performancemonitor': {'_TYPE': 'member'},
    'enterprise_performancemonitor': {'_TYPE': 'child'},
    'permission': {},
    'nsport_permission': {'_TYPE': 'child'},
    'domain_permission': {'_TYPE': 'child'},
    'zone_permission': {'_TYPE': 'child'},
    'service_permission': {'_TYPE': 'child'},
    'l2domaintemplate_permission': {'_TYPE': 'child'},
    'l2domain_permission': {'_TYPE': 'child'},
    'vlan_permission': {'_TYPE': 'child'},
    'domaintemplate_permission': {'_TYPE': 'child'},
    'gateway_permission': {'_TYPE': 'child'},
    'nsgateway_permission': {'_TYPE': 'child'},
    'vsgredundantport_permission': {'_TYPE': 'child'},
    'redundancygroup_permission': {'_TYPE': 'child'},
    'port_permission': {'_TYPE': 'child'},
    'pgexpression': {},
    'domain_pgexpression': {'_TYPE': 'child'},
    'l2domain_pgexpression': {'_TYPE': 'child'},
    'pgexpressiontemplate': {},
    'l2domaintemplate_pgexpressiontemplate': {'_TYPE': 'child'},
    'domaintemplate_pgexpressiontemplate': {'_TYPE': 'child'},
    'policydecision': {},
    'containerinterface_policydecision': {'_TYPE': 'child'},
    'vminterface_policydecision': {'_TYPE': 'child'},
    'hostinterface_policydecision': {'_TYPE': 'child'},
    'bridgeinterface_policydecision': {'_TYPE': 'child'},
    'policyentry': {},
    'policystatement_policyentry': {'_TYPE': 'child'},
    'policygroup': {},
    'containerinterface_policygroup': {'_TYPE': 'child'},
    'domain_policygroup': {'_TYPE': 'child'},
    'l2domain_policygroup': {'_TYPE': 'child'},
    'hostinterface_policygroup': {'_TYPE': 'child'},
    'bridgeinterface_policygroup': {'_TYPE': 'child'},
    'vminterface_policygroup': {'_TYPE': 'child'},
    'vport_policygroup': {'_TYPE': 'member'},
    'policygrouptemplate': {},
    'l2domaintemplate_policygrouptemplate': {'_TYPE': 'child'},
    'domaintemplate_policygrouptemplate': {'_TYPE': 'child'},
    'policyobjectgroup': {},
    'enterprise_policyobjectgroup': {'_TYPE': 'child'},
    'policystatement': {},
    'link_policystatement': {'_TYPE': 'child'},
    'port': {},
    'redundancygroup_port': {'_TYPE': 'child'},
    'gateway_port': {'_TYPE': 'child'},
    'autodiscoveredgateway_port': {'_TYPE': 'child'},
    'portmapping': {},
    'vport_portmapping': {'_TYPE': 'child'},
    'porttemplate': {},
    'gatewaytemplate_porttemplate': {'_TYPE': 'child'},
    'proxyarpfilter': {},
    'subnet_proxyarpfilter': {'_TYPE': 'child'},
    'psnatpool': {},
    'link_psnatpool': {'_TYPE': 'child'},
    'pspatmap': {},
    'psnatpool_pspatmap': {'_TYPE': 'child'},
    'ptranslationmap': {},
    'psnatpool_ptranslationmap': {'_TYPE': 'child'},
    'publicnetwork': {},
    'enterprise_publicnetwork': {'_TYPE': 'child'},
    'qos': {},
    'subnet_qos': {'_TYPE': 'child'},
    'domain_qos': {'_TYPE': 'child'},
    'zone_qos': {'_TYPE': 'child'},
    'l2domaintemplate_qos': {'_TYPE': 'child'},
    'l2domain_qos': {'_TYPE': 'child'},
    'domaintemplate_qos': {'_TYPE': 'child'},
    'hostinterface_qos': {'_TYPE': 'child'},
    'bridgeinterface_qos': {'_TYPE': 'child'},
    'zonetemplate_qos': {'_TYPE': 'child'},
    'subnettemplate_qos': {'_TYPE': 'child'},
    'vport_qos': {'_TYPE': 'child'},
    'policydecision_qos': {'_TYPE': 'child'},
    'qospolicer': {},
    'ratelimiter': {},
    'enterprise_ratelimiter': {'_TYPE': 'child'},
    'redirectiontarget': {},
    'containerinterface_redirectiontarget': {'_TYPE': 'child'},
    'domain_redirectiontarget': {'_TYPE': 'child'},
    'l2domain_redirectiontarget': {'_TYPE': 'child'},
    'hostinterface_redirectiontarget': {'_TYPE': 'child'},
    'bridgeinterface_redirectiontarget': {'_TYPE': 'child'},
    'vminterface_redirectiontarget': {'_TYPE': 'child'},
    'vport_redirectiontarget': {'_TYPE': 'member'},
    'redirectiontargettemplate': {},
    'l2domaintemplate_redirectiontargettemplate': {'_TYPE': 'child'},
    'domaintemplate_redirectiontargettemplate': {'_TYPE': 'child'},
    'redundancygroup': {},
    'enterprise_redundancygroup': {'_TYPE': 'child'},
    'resync': {},
    'subnet_resync': {'_TYPE': 'child'},
    'vm_resync': {'_TYPE': 'child'},
    'routingpolicy': {},
    'domain_routingpolicy': {'_TYPE': 'child'},
    'enterprise_routingpolicy': {'_TYPE': 'child'},
    'service': {},
    'redundancygroup_service': {'_TYPE': 'child'},
    'gateway_service': {'_TYPE': 'child'},
    'autodiscoveredgateway_service': {'_TYPE': 'child'},
    'sharednetworkresource': {},
    'patmapper_sharednetworkresource': {'_TYPE': 'member'},
    'enterprise_sharednetworkresource': {'_TYPE': 'child'},
    'site': {},
    'spatsourcespool': {},
    'domain_spatsourcespool': {'_TYPE': 'child'},
    'sshkey': {},
    'infrastructureaccessprofile_sshkey': {'_TYPE': 'child'},
    'ssidconnection': {},
    'wirelessport_ssidconnection': {'_TYPE': 'child'},
    'staticroute': {},
    'containerinterface_staticroute': {'_TYPE': 'child'},
    'domain_staticroute': {'_TYPE': 'child'},
    'sharednetworkresource_staticroute': {'_TYPE': 'child'},
    'hostinterface_staticroute': {'_TYPE': 'child'},
    'vminterface_staticroute': {'_TYPE': 'child'},
    'statistics': {},
    'containerinterface_statistics': {'_TYPE': 'child'},
    'ingressadvfwdentrytemplate_statistics': {'_TYPE': 'child'},
    'domain_statistics': {'_TYPE': 'child'},
    'zone_statistics': {'_TYPE': 'child'},
    'subnet_statistics': {'_TYPE': 'child'},
    'patnatpool_statistics': {'_TYPE': 'child'},
    'l2domain_statistics': {'_TYPE': 'child'},
    'vlan_statistics': {'_TYPE': 'child'},
    'virtualfirewallrule_statistics': {'_TYPE': 'child'},
    'egressaclentrytemplate_statistics': {'_TYPE': 'child'},
    'ingressexternalserviceentrytemplate_statistics': {'_TYPE': 'child'},
    'bridgeinterface_statistics': {'_TYPE': 'child'},
    'egressadvfwdentrytemplate_statistics': {'_TYPE': 'child'},
    'vminterface_statistics': {'_TYPE': 'child'},
    'hostinterface_statistics': {'_TYPE': 'child'},
    'addressmap_statistics': {'_TYPE': 'child'},
    'vport_statistics': {'_TYPE': 'child'},
    'ingressaclentrytemplate_statistics': {'_TYPE': 'child'},
    'nsport_statistics': {'_TYPE': 'child'},
    'wirelessport_statistics': {'_TYPE': 'child'},
    'statisticscollector': {},
    'statisticspolicy': {},
    'subnet_statisticspolicy': {'_TYPE': 'child'},
    'domain_statisticspolicy': {'_TYPE': 'child'},
    'zone_statisticspolicy': {'_TYPE': 'child'},
    'l2domain_statisticspolicy': {'_TYPE': 'child'},
    'addressmap_statisticspolicy': {'_TYPE': 'child'},
    'vport_statisticspolicy': {'_TYPE': 'child'},
    'patnatpool_statisticspolicy': {'_TYPE': 'child'},
    'nsport_statisticspolicy': {'_TYPE': 'child'},
    'subnet': {},
    'ikegatewayconnection_subnet': {'_TYPE': 'child'},
    'domain_subnet': {'_TYPE': 'child'},
    'zone_subnet': {'_TYPE': 'child'},
    'nsgateway_subnet': {'_TYPE': 'child'},
    'subnettemplate_subnet': {'_TYPE': 'child'},
    'patmapper_subnet': {'_TYPE': 'child'},
    'subnettemplate': {},
    'domaintemplate_subnettemplate': {'_TYPE': 'child'},
    'zonetemplate_subnettemplate': {'_TYPE': 'child'},
    'systemconfig': {},
    'tca': {},
    'containerinterface_tca': {'_TYPE': 'child'},
    'subnet_tca': {'_TYPE': 'child'},
    'domain_tca': {'_TYPE': 'child'},
    'zone_tca': {'_TYPE': 'child'},
    'l2domain_tca': {'_TYPE': 'child'},
    'hostinterface_tca': {'_TYPE': 'child'},
    'bridgeinterface_tca': {'_TYPE': 'child'},
    'vminterface_tca': {'_TYPE': 'child'},
    'vport_tca': {'_TYPE': 'child'},
    'tier': {},
    'performancemonitor_tier': {'_TYPE': 'child'},
    'trunk': {},
    'vport_trunk': {'_TYPE': 'child'},
    'enterprise_trunk': {'_TYPE': 'child'},
    'underlay': {},
    'uplinkconnection_underlay': {'_TYPE': 'child'},
    'uplinkconnection': {},
    'nsgateway_uplinkconnection': {'_TYPE': 'child'},
    'vlan_uplinkconnection': {'_TYPE': 'child'},
    'vlantemplate_uplinkconnection': {'_TYPE': 'child'},
    'uplinkroutedistinguisher': {},
    'domain_uplinkroutedistinguisher': {'_TYPE': 'child'},
    'l2domain_uplinkroutedistinguisher': {'_TYPE': 'child'},
    'user': {},
    'group_user': {'_TYPE': 'member'},
    'enterprise_user': {'_TYPE': 'child'},
    'usercontext': {},
    'vcenter': {},
    'vcentercluster': {},
    'vcenterdatacenter_vcentercluster': {'_TYPE': 'child'},
    'vcenterdatacenter': {},
    'vcenter_vcenterdatacenter': {'_TYPE': 'child'},
    'vcenterhypervisor': {},
    'vcentercluster_vcenterhypervisor': {'_TYPE': 'child'},
    'vcenterdatacenter_vcenterhypervisor': {'_TYPE': 'child'},
    'virtualfirewallpolicy': {},
    'l2domaintemplate_virtualfirewallpolicy': {'_TYPE': 'child'},
    'domain_virtualfirewallpolicy': {'_TYPE': 'child'},
    'domaintemplate_virtualfirewallpolicy': {'_TYPE': 'child'},
    'l2domain_virtualfirewallpolicy': {'_TYPE': 'child'},
    'virtualfirewallrule': {},
    'virtualfirewallpolicy_virtualfirewallrule': {'_TYPE': 'child'},
    'virtualip': {},
    'subnet_virtualip': {'_TYPE': 'child'},
    'vport_virtualip': {'_TYPE': 'child'},
    'redirectiontarget_virtualip': {'_TYPE': 'child'},
    'vlan': {},
    'nsport_vlan': {'_TYPE': 'child'},
    'nsredundantport_vlan': {'_TYPE': 'child'},
    'vsgredundantport_vlan': {'_TYPE': 'child'},
    'port_vlan': {'_TYPE': 'child'},
    'vlantemplate': {},
    'nsporttemplate_vlantemplate': {'_TYPE': 'child'},
    'porttemplate_vlantemplate': {'_TYPE': 'child'},
    'vm': {},
    'vrs_vm': {'_TYPE': 'child'},
    'subnet_vm': {'_TYPE': 'child'},
    'domain_vm': {'_TYPE': 'child'},
    'qos_vm': {'_TYPE': 'child'},
    'zone_vm': {'_TYPE': 'child'},
    'egressacltemplate_vm': {'_TYPE': 'child'},
    'l2domain_vm': {'_TYPE': 'child'},
    'user_vm': {'_TYPE': 'child'},
    'enterprise_vm': {'_TYPE': 'child'},
    'vport_vm': {'_TYPE': 'child'},
    'ingressacltemplate_vm': {'_TYPE': 'child'},
    'vminterface': {},
    'subnet_vminterface': {'_TYPE': 'child'},
    'domain_vminterface': {'_TYPE': 'child'},
    'zone_vminterface': {'_TYPE': 'child'},
    'l2domain_vminterface': {'_TYPE': 'child'},
    'vm_vminterface': {'_TYPE': 'child'},
    'vport_vminterface': {'_TYPE': 'child'},
    'vnf': {},
    'enterprise_vnf': {'_TYPE': 'child'},
    'vnfcatalog': {},
    'vnfdescriptor': {},
    'vnfcatalog_vnfdescriptor': {'_TYPE': 'child'},
    'vnfdomainmapping': {},
    'domain_vnfdomainmapping': {'_TYPE': 'child'},
    'vnfinterface': {},
    'vnf_vnfinterface': {'_TYPE': 'child'},
    'vport_vnfinterface': {'_TYPE': 'child'},
    'vnfinterfacedescriptor': {},
    'vnfdescriptor_vnfinterfacedescriptor': {'_TYPE': 'child'},
    'vnfmetadata': {},
    'vnf_vnfmetadata': {'_TYPE': 'child'},
    'enterprise_vnfmetadata': {'_TYPE': 'child'},
    'vnfthresholdpolicy': {},
    'enterprise_vnfthresholdpolicy': {'_TYPE': 'child'},
    'vpnconnection': {},
    'sharednetworkresource_vpnconnection': {'_TYPE': 'child'},
    'l2domain_vpnconnection': {'_TYPE': 'child'},
    'domain_vpnconnection': {'_TYPE': 'child'},
    'vport': {},
    'vrs_vport': {'_TYPE': 'child'},
    'subnet_vport': {'_TYPE': 'child'},
    'domain_vport': {'_TYPE': 'child'},
    'redirectiontarget_vport': {'_TYPE': 'member'},
    'zone_vport': {'_TYPE': 'child'},
    'floatingip_vport': {'_TYPE': 'child'},
    'l2domain_vport': {'_TYPE': 'child'},
    'overlaymirrordestination_vport': {'_TYPE': 'member'},
    'trunk_vport': {'_TYPE': 'child'},
    'policygroup_vport': {'_TYPE': 'member'},
    'multinicvport_vport': {'_TYPE': 'child'},
    'vportmirror': {},
    'vport_vportmirror': {'_TYPE': 'child'},
    'mirrordestination_vportmirror': {'_TYPE': 'child'},
    'vrs': {},
    'hsc_vrs': {'_TYPE': 'child'},
    'vport_vrs': {'_TYPE': 'child'},
    'vsc_vrs': {'_TYPE': 'child'},
    'container_vrs': {'_TYPE': 'child'},
    'vm_vrs': {'_TYPE': 'child'},
    'vrsaddressrange': {},
    'vrsconfig_vrsaddressrange': {'_TYPE': 'child'},
    'vcenter_vrsaddressrange': {'_TYPE': 'child'},
    'vcentercluster_vrsaddressrange': {'_TYPE': 'child'},
    'vcenterhypervisor_vrsaddressrange': {'_TYPE': 'child'},
    'vcenterdatacenter_vrsaddressrange': {'_TYPE': 'child'},
    'vrsconfig': {},
    'vrsmetrics': {},
    'vcenterhypervisor_vrsmetrics': {'_TYPE': 'child'},
    'vrsredeploymentpolicy': {},
    'vrsconfig_vrsredeploymentpolicy': {'_TYPE': 'child'},
    'vcenter_vrsredeploymentpolicy': {'_TYPE': 'child'},
    'vcentercluster_vrsredeploymentpolicy': {'_TYPE': 'child'},
    'vcenterhypervisor_vrsredeploymentpolicy': {'_TYPE': 'child'},
    'vcenterdatacenter_vrsredeploymentpolicy': {'_TYPE': 'child'},
    'vsc': {},
    'vsp_vsc': {'_TYPE': 'child'},
    'vrs_vsc': {'_TYPE': 'child'},
    'vsd': {},
    'vsp_vsd': {'_TYPE': 'child'},
    'vsgredundantport': {},
    'redundancygroup_vsgredundantport': {'_TYPE': 'child'},
    'vsp': {},
    'wirelessport': {},
    'nsgateway_wirelessport': {'_TYPE': 'child'},
    'zfbautoassignment': {},
    'zfbrequest': {},
    'enterprise_zfbrequest': {'_TYPE': 'child'},
    'zone': {},
    'domain_zone': {'_TYPE': 'child'},
    'zonetemplate': {},
    'domaintemplate_zonetemplate': {'_TYPE': 'child'},
}

INVARIANT_RESOURCES = [
    'brconnections',
    'cms',
    'licensestatus',
    'ltestatistics',
    'qos',
    'statistics',
    'vrsmetrics'
]


def parse_config(config_file):
    """
    Parses configuration file
    """
    cfg = ConfigParser.ConfigParser()
    cfg.read(config_file)

    # Checking the LOG options
    if not cfg.has_option('LOG', 'directory') or \
            not cfg.has_option('LOG', 'file') or \
            not cfg.has_option('LOG', 'level'):
        print 'Missing options in the LOG section of configuration file {0:s}, please check the sample configuration'.format(config_file)
        sys.exit(1)

    return cfg


def configure_logging(level, path):
    """
    Configures the logging environment
    """
    logging.basicConfig(filename=path, format='%(asctime)s %(levelname)s %(message)s', level=level)
    logger = logging.getLogger(__name__)

    return logger


def init_base_entities():
    """
    Sets up basic entities for use
    """
    global NUAGE_API_DATA

    csproot = vsdk.NUUser(
        id=str(uuid.uuid1()),
        user_name='csproot',
        password='csproot',
        first_name='csproot',
        last_name='csproot',
        email='csproot@CSP.com',
        parent_type='ENTERPRISE'
    )
    csp = vsdk.NUEnterprise(
        id=str(uuid.uuid1()),
        name='CSP',
        description='Enterprise that contains all the CSP users',
        allowed_forwarding_classes=['E', 'F', 'G', 'H'],
        allow_gateway_management=True,
        allow_advanced_qos_configuration=True,
        allow_trusted_forwarding_class=True,
        bgp_enabled=True,
        creation_date=1383734246000,
        customer_id=10002,
        dictionary_version=2,
        enable_application_performance_management=False,
        entity_scope='ENTERPRISE',
        floating_ips_quota=0,
        floating_ips_used=0,
        ldap_authorization_enabled=False,
        ldap_enabled=False,
        last_updated_by=csproot.id,
        last_updated_date=1499101329000
    )
    csproot.parent_id = csp.id

    NUAGE_API_DATA['enterprise_user'][csp.id] = {csproot.id: csproot}
    NUAGE_API_DATA['ROOT_UUIDS']['csp_enterprise'] = csp.id
    NUAGE_API_DATA['enterprise'][csp.id] = csp
    NUAGE_API_DATA['ROOT_UUIDS']['csproot_user'] = csproot.id
    NUAGE_API_DATA['user'][csproot.id] = csproot

    logging.info('Created base entities')
    logging.debug(NUAGE_API_DATA)


def _string_clean(string):
    rep = {
        "IPID": "IpID",
        "VCenter": "Vcenter",
        "vCenter": "Vcenter",
        "VPort": "Vport",
        "IPv6": "Ipv6",
        "IPv4": "Ipv4"
    }

    rep = dict((re.escape(k), v) for k, v in rep.items())
    pattern = re.compile("|".join(list(rep.keys())))

    return pattern.sub(lambda m: rep[re.escape(m.group(0))], string)


def get_idiomatic_name(name):
    first_cap_re = re.compile("(.)([A-Z](?!s([A-Z])*)[a-z]+)")
    all_cap_re = re.compile("([a-z0-9])([A-Z])")

    s1 = first_cap_re.sub(r"\1_\2", _string_clean(name))

    return all_cap_re.sub(r"\1_\2", s1).lower()


def get_singular_name(plural_name):
    if plural_name in INVARIANT_RESOURCES:
        return plural_name

    if plural_name[-3:] == 'ies':
        return plural_name[:-3] + 'y'

    if plural_name[-1:] == 's':
        return plural_name[:-1]